import java.io.*;

public class ExitCode
{
	private static int THREAD_TIMEOUT = 60000;

	private static boolean isWindows()
	{
		return System.getProperty("os.name", "").toUpperCase().startsWith("WIN");
	}

	public static void main(String args[])
	{
		if (args.length > 0)
		{
			String cmd = "";
			for (int i = 0; i < args.length; i++)
			{
				if (i > 0) cmd += " ";
				cmd += args[i];
			}

			ExitCode ec = new ExitCode();
			
			StringBuffer stdout = new StringBuffer();
			StringBuffer stderr = new StringBuffer();

			System.out.println("Going to execute: " + cmd);
			try
			{
				int ret = ec.runCommand(cmd, stdout, stderr);
				if (stdout.length() > 0)
				{
					System.out.print(stdout.toString());
				}
				if (stderr.length() > 0)
				{
					System.err.print(stderr.toString());
				}
				System.out.println("Exit code was: " + ret);
			}
			catch (Exception ex)
			{	
				ex.printStackTrace();
			}	
		}
	}


	private int runCommand(String cmd, StringBuffer stdout, StringBuffer stderr) throws Exception
	{
		Runtime rt = Runtime.getRuntime();
		if (isWindows()) 
		{
			cmd = "cmd /c " + cmd;
		}

		Process proc = rt.exec(cmd);
		StreamWatcher errThread = new StreamWatcher(proc.getErrorStream());
		errThread.start();
		StreamWatcher outThread = new StreamWatcher(proc.getInputStream());
		outThread.start();
		int pstat = proc.waitFor();
		errThread.join(THREAD_TIMEOUT);
		outThread.join(THREAD_TIMEOUT);
		if (stdout != null)
		{
			stdout.append(outThread.getBuffer());
		}
		if (stderr != null)
		{
			stderr.append(errThread.getBuffer());
		}
		
		return pstat;
	}
}

class StreamWatcher extends Thread 
{
	private static String lineSeparator = System.getProperty("line.separator");
	
	private StringBuffer buf = new StringBuffer();
	private InputStream in;
	public StreamWatcher(InputStream in) 
	{
	    this.in = in;
	}
	public StringBuffer getBuffer() 
	{
	    return buf;
	}
	public void run() 
	{
  	    BufferedReader breader = null;
	    try 
	    {
	        breader = new BufferedReader(new InputStreamReader (in));
			String line = breader.readLine();
			while (line!=null)
			{
			    buf.append(line);
			    buf.append(lineSeparator);
			    line = breader.readLine();
			}
	    } 
	    catch (Exception e) 
	    {
			System.err.println("Error reading input stream : " + e);
	    } 
	    finally 
	    {
			try 
			{
			    in.close();
			} 
			catch(Exception e) 
			{
			}
	    }
	}
}
    
